Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(549)

Unified Diff: third_party/WebKit/public/platform/Platform.h

Issue 1845323002: Remove WebUnitTestSupport (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/platform/Platform.h
diff --git a/third_party/WebKit/public/platform/Platform.h b/third_party/WebKit/public/platform/Platform.h
index 69a8832d5f18f3186663ee82c4be755db31671bc..35354833dc95c565f91466a144302353752dd72a 100644
--- a/third_party/WebKit/public/platform/Platform.h
+++ b/third_party/WebKit/public/platform/Platform.h
@@ -113,11 +113,10 @@ struct WebFloatPoint;
class WebThemeEngine;
class WebThread;
class WebTrialTokenValidator;
-class WebURL;
class WebURLLoader;
+class WebURLLoaderMockFactory;
+class WebURLResponse;
class WebURLResponse;
-class WebUnitTestSupport;
-struct WebLocalizedString;
struct WebSize;
class BLINK_PLATFORM_EXPORT Platform {
@@ -412,8 +411,8 @@ public:
// Testing -------------------------------------------------------------
- // Get a pointer to testing support interfaces. Will not be available in production builds.
- virtual WebUnitTestSupport* unitTestSupport() { return nullptr; }
+ // Gets a pointer to URLLoaderMockFactory for testing. Will not be available in production builds.
+ virtual WebURLLoaderMockFactory* getURLLoaderMockFactory() { return nullptr; }
// Record to a RAPPOR privacy-preserving metric, see: https://www.chromium.org/developers/design-documents/rappor.
// recordRappor records a sample string, while recordRapporURL records the domain and registry of a url.
« no previous file with comments | « third_party/WebKit/public/blink_headers.gypi ('k') | third_party/WebKit/public/platform/WebUnitTestSupport.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698